@@ -10,7 +10,8 @@
 #' be considered. You can also pass custom variables labels with the
 #' `variable_labels` argument.
 #'
-#' @param data a data frame
+#' @param data a data frame, a data frame extension (e.g. a tibble),
+#' or a survey design object
 #' @param include variables to include, accepts [tidy-select][dplyr::select]
 #' syntax
 #' @param weights optional variable name of a weighting variable,
@@ -294,7 +295,9 @@ gglikert <- function(data,
   }
 
   if (add_totals) {
-    dtot <- data |>
+    d <- data
+    if (reverse_likert) d$.answer <- forcats::fct_rev(d$.answer)
+    dtot <- d |>
       dplyr::group_by(.data[[y]], !!!facet_rows, !!!facet_cols) |>
       dplyr::summarise(
         prop_lower = .prop_lower(
@@ -393,7 +396,8 @@ gglikert <- function(data,
       legend.position = "bottom",
       panel.grid.major.y = element_blank()
     ) +
-    scale_fill_likert(cutoff = cutoff)
+    scale_fill_likert(cutoff = cutoff) +
+    guides(fill = guide_legend(reverse = reverse_likert))
 
   p + facet_grid(
     rows = facet_rows, cols = facet_cols,
@@ -418,6 +422,20 @@ gglikert_data <- function(data,
                           data_fun = NULL) {
   rlang::check_installed("labelled")
 
+  if (inherits(data, "survey.design")) {
+    survey_weights <- stats::weights(data)
+    data <- data$variables
+    weights <- enquo(weights)
+    if (!rlang::quo_is_null(weights))
+      cli::cli_abort(paste(
+        "{.arg data} is a survey object:",
+        "you can't pass a {.arg weights} argument.",
+        "Survey weights from the survey object will automatically be retrieved."
+      ))
+    data$survey_weights <- survey_weights
+    weights <- dplyr::all_of("survey_weights")
+  }
+
   sort <- match.arg(sort)
   sort_method <- match.arg(sort_method)
 
@@ -772,7 +790,8 @@ gglikert_stacked <- function(data,
       legend.position = "bottom",
       panel.grid.major.y = element_blank()
     ) +
-    scale_fill_extended()
+    scale_fill_extended() +
+    guides(fill = guide_legend(reverse = !reverse_fill))
 
   p
 }
