@@ -6,33 +6,41 @@ test_that("ggcoef_model()", {
   data(tips, package = "reshape")
   mod_simple <- lm(tip ~ day + time + total_bill, data = tips)
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() mod simple",
     ggcoef_model(mod_simple)
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() mod simple no guide",
     ggcoef_model(mod_simple, shape_guide = FALSE, colour_guide = FALSE)
   )
 
+  expect_error(
+    mod_simple |> ggcoef_dodged()
+  )
+
+  expect_error(
+    mod_simple |> ggcoef_faceted()
+  )
+
   # custom variable labels
   # you can use to define variable labels before computing model
   if (requireNamespace("labelled")) {
-    tips_labelled <- tips %>%
+    tips_labelled <- tips |>
       labelled::set_variable_labels(
         day = "Day of the week",
         time = "Lunch or Dinner",
         total_bill = "Bill's total"
       )
     mod_labelled <- lm(tip ~ day + time + total_bill, data = tips_labelled)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       "ggcoef_model() mod labelled",
       ggcoef_model(mod_labelled)
     )
   }
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() mod simple with variable labels",
     ggcoef_model(
       mod_simple,
@@ -45,7 +53,7 @@ test_that("ggcoef_model()", {
   )
 
   # if labels are too long, you can use 'facet_labeller' to wrap them
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() mod simple facet_labeller",
     ggcoef_model(
       mod_simple,
@@ -59,7 +67,7 @@ test_that("ggcoef_model()", {
   )
 
   # do not display variable facets but add colour guide
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() mod simple no variable facets",
     ggcoef_model(
       mod_simple,
@@ -78,31 +86,31 @@ test_that("ggcoef_model()", {
     family = binomial
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() logistic regression",
     ggcoef_model(mod_titanic, exponentiate = TRUE)
   )
 
   # display intercept
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() logistic regression with intercept",
     ggcoef_model(mod_titanic, exponentiate = TRUE, intercept = TRUE)
   )
 
   # display only a subset of terms
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() logistic regression subset",
     ggcoef_model(mod_titanic, exponentiate = TRUE, include = c("Age", "Class"))
   )
 
   # do not change points' shape based on significance
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() logistic regression no significance",
     ggcoef_model(mod_titanic, exponentiate = TRUE, significance = NULL)
   )
 
   # a black and white version
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() logistic regression black and white",
     ggcoef_model(
       mod_titanic,
@@ -113,7 +121,7 @@ test_that("ggcoef_model()", {
   )
 
   # show dichotomous terms on one row
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() logistic regression no reference row",
     ggcoef_model(
       mod_titanic,
@@ -130,7 +138,7 @@ test_that("ggcoef_model()", {
     tip ~ poly(total_bill, 3) + day,
     data = tips,
   )
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() polynomial terms",
     ggcoef_model(mod_poly)
   )
@@ -143,7 +151,7 @@ test_that("ggcoef_model()", {
       data = tips,
       contrasts = list(time = contr.sum, day = contr.treatment(4, base = 3))
     )
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       "ggcoef_model() different types of contrasts",
       ggcoef_model(mod2)
     )
@@ -164,16 +172,21 @@ test_that("ggcoef_compare()", {
     "With interaction" = mod3
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_compare() dodged",
     ggcoef_compare(models)
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_compare() faceted",
     ggcoef_compare(models, type = "faceted")
   )
 
+  expect_doppelganger(
+    "ggcoef_compare() table",
+    ggcoef_compare(models, type = "table")
+  )
+
   d <- as.data.frame(Titanic)
   m1 <- glm(Survived ~ Sex + Age, family = binomial, data = d, weights = Freq)
   m2 <- glm(
@@ -184,29 +197,33 @@ test_that("ggcoef_compare()", {
   )
   models <- list("Model 1" = m1, "Model 2" = m2)
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_compare() titanic dodged",
     ggcoef_compare(models)
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_compare() titanic faceted",
     ggcoef_compare(models, type = "faceted")
   )
 
+  expect_doppelganger(
+    "ggcoef_compare() titanic table",
+    ggcoef_compare(models, type = "table")
+  )
+
   rd <- ggcoef_compare(models, return_data = TRUE)
   expect_equal(
     levels(rd$label),
     c("Male", "Female", "Child", "Adult", "1st", "2nd", "3rd", "Crew")
   )
 
-  expect_error(
-    ggcoef_compare(models, add_reference_rows = FALSE),
-    NA
+  expect_no_error(
+    ggcoef_compare(models, add_reference_rows = FALSE)
   )
 })
 
-test_that("ggcoef_multinom()", {
+test_that("ggcoef_*() and multinom models", {
   skip_if_not_installed("broom.helpers")
   skip_if_not_installed("nnet")
   skip_on_cran()
@@ -219,27 +236,31 @@ test_that("ggcoef_multinom()", {
     weights = hec$Freq
   )
 
-  vdiffr::expect_doppelganger(
-    "ggcoef_multinom() dodged",
-    ggcoef_multinom(mod, exponentiate = TRUE)
+  expect_doppelganger(
+    "ggcoef_model() multinom",
+    ggcoef_model(mod, exponentiate = TRUE)
   )
 
-  vdiffr::expect_doppelganger(
-    "ggcoef_multinom() faceted",
-    ggcoef_multinom(mod, type = "faceted")
+  expect_doppelganger(
+    "ggcoef_table() multinom",
+    ggcoef_table(mod, exponentiate = TRUE)
   )
 
-  vdiffr::expect_doppelganger(
-    "ggcoef_multinom() table",
-    ggcoef_multinom(mod, type = "table", exponentiate = TRUE)
+  expect_doppelganger(
+    "ggcoef_dodged() multinom",
+    ggcoef_dodged(mod, exponentiate = TRUE)
   )
 
-  vdiffr::expect_doppelganger(
-    "ggcoef_multinom() faceted custom y level label",
-    ggcoef_multinom(
+  expect_doppelganger(
+    "ggcoef_faceted() multinom",
+    ggcoef_faceted(mod, exponentiate = TRUE)
+  )
+
+  expect_doppelganger(
+    "ggcoef_faceted() with custom group_labels",
+    ggcoef_faceted(
       mod,
-      type = "faceted",
-      y.level_label = c("Brown" = "Brown\n(ref: Black)"),
+      group_labels = c("Brown" = "Brown\n(ref: Black)"),
       exponentiate = TRUE
     )
   )
@@ -252,11 +273,11 @@ test_that("ggcoef_model() works with tieders not returning p-values", {
 
   mod <- lm(Sepal.Width ~ Species, iris)
   my_tidier <- function(x, ...) {
-    x %>%
-      broom::tidy(...) %>%
+    x |>
+      broom::tidy(...) |>
       dplyr::select(-dplyr::all_of("p.value"))
   }
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_model() no p values",
     ggcoef_model(mod, tidy_fun = my_tidier)
   )
@@ -295,7 +316,7 @@ test_that("ggcoef_compare() does not produce an error with an include", {
   )
   models <- list("Model 1" = m1, "Model 2" = m2)
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_compare() with include",
     ggcoef_compare(models, include = broom.helpers::starts_with("p"))
   )
@@ -305,30 +326,27 @@ test_that("ggcoef_model() works with pairwise contratst", {
   skip_if_not_installed("broom.helpers")
   skip_if_not_installed("emmeans")
   mod <- lm(Sepal.Length ~ Sepal.Width + Species, data = iris)
-  expect_error(
-    ggcoef_model(mod, add_pairwise_contrasts = TRUE),
-    NA
+  expect_no_error(
+    ggcoef_model(mod, add_pairwise_contrasts = TRUE)
   )
-  expect_error(
+  expect_no_error(
     ggcoef_model(
       mod,
       add_pairwise_contrasts = TRUE,
       pairwise_variables = dplyr::starts_with("Sp"),
       keep_model_terms = TRUE
-    ),
-    NA
+    )
   )
   mod2 <- lm(Sepal.Length ~ Species, data = iris)
-  expect_error(
-    ggcoef_compare(list(mod, mod2), add_pairwise_contrasts = TRUE),
-    NA
+  expect_no_error(
+    ggcoef_compare(list(mod, mod2), add_pairwise_contrasts = TRUE)
   )
 })
 
 test_that("tidy_args is supported", {
   mod <- lm(Sepal.Length ~ Sepal.Width, data = iris)
   custom <- function(x, force = 1, ...) {
-    broom::tidy(x, ...) %>%
+    broom::tidy(x, ...) |>
       dplyr::mutate(estimate = force)
   }
   res <- ggcoef_model(
@@ -349,17 +367,17 @@ test_that("ggcoef_table()", {
   data(tips, package = "reshape")
   mod_simple <- lm(tip ~ day + time + total_bill, data = tips)
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() mod simple",
     ggcoef_table(mod_simple)
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() table_stat",
     ggcoef_table(mod_simple, table_stat = c("p.value", "ci"))
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() table_header",
     ggcoef_table(mod_simple, table_header = c("A", "B", "C"))
   )
@@ -368,12 +386,12 @@ test_that("ggcoef_table()", {
     ggcoef_table(mod_simple, table_header = c("A", "B", "C", "D"))
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() table_text_size",
     ggcoef_table(mod_simple, table_text_size = 5)
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() table_stat_label ",
     ggcoef_table(
       mod_simple,
@@ -383,37 +401,37 @@ test_that("ggcoef_table()", {
     )
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() ci_pattern",
     ggcoef_table(mod_simple, ci_pattern = "{conf.low} to {conf.high}")
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() table_widths",
-    ggcoef_table(mod_simple, table_witdhs = c(1, 2))
+    ggcoef_table(mod_simple, table_widths = c(1, 2))
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() stripped_rows",
     ggcoef_table(mod_simple, stripped_rows = FALSE)
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() show_p_values & signif_stars",
     ggcoef_table(mod_simple, show_p_values = TRUE, signif_stars = TRUE)
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() show_p_values only",
     ggcoef_table(mod_simple, show_p_values = TRUE, signif_stars = FALSE)
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() signif_stars only",
     ggcoef_table(mod_simple, show_p_values = FALSE, signif_stars = TRUE)
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "ggcoef_table() customized statistics",
     ggcoef_table(
       mod_simple,
@@ -427,12 +445,12 @@ test_that("ggcoef_table()", {
         label = toupper
       ),
       table_header = c("Term", "Coef.", "SE", "CI"),
-      table_witdhs = c(2, 3)
+      table_widths = c(2, 3)
     )
   )
 })
 
-test_that("ggcoef_multicomponents()", {
+test_that("ggcoef_*() and multicomponents models", {
   skip_on_cran()
   skip_if_not_installed("broom.helpers")
   skip_if_not_installed("pscl")
@@ -441,146 +459,34 @@ test_that("ggcoef_multicomponents()", {
   data("bioChemists", package = "pscl")
   mod <- zeroinfl(art ~ fem * mar | fem + mar, data = bioChemists)
 
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() dodged",
-    ggcoef_multicomponents(mod, tidy_fun = broom.helpers::tidy_zeroinfl)
+  expect_doppelganger(
+    "ggcoef_model() zeroinfl",
+    ggcoef_model(mod)
   )
 
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() faceted",
-    ggcoef_multicomponents(
+  expect_doppelganger(
+    "ggcoef_table() zeroinfl",
+    ggcoef_table(mod)
+  )
+
+  expect_doppelganger(
+    "ggcoef_dodged() zeroinfl",
+    ggcoef_dodged(mod)
+  )
+
+  expect_doppelganger(
+    "ggcoef_faceted() zeroinfl",
+    ggcoef_faceted(mod)
+  )
+
+  expect_doppelganger(
+    "ggcoef_faceted() zeroinfl with custom group_labels",
+    ggcoef_faceted(
       mod,
-      tidy_fun = broom.helpers::tidy_zeroinfl,
-      type = "f"
+      group_labels = c(
+        conditional = "Count",
+        zero_inflated = "Zero-inflated"
+      )
     )
   )
-
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() faceted exponentiated",
-    ggcoef_multicomponents(
-      mod,
-      tidy_fun = broom.helpers::tidy_zeroinfl,
-      type = "f",
-      exponentiate = TRUE
-    )
-  )
-
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() table",
-    ggcoef_multicomponents(
-      mod,
-      tidy_fun = broom.helpers::tidy_zeroinfl,
-      type = "t"
-    )
-  )
-
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() table exponentiated",
-    ggcoef_multicomponents(
-      mod,
-      tidy_fun = broom.helpers::tidy_zeroinfl,
-      type = "t",
-      exponentiate = TRUE
-    )
-  )
-
-  expect_s3_class(
-    ggcoef_multicomponents(
-      mod,
-      tidy_fun = broom.helpers::tidy_zeroinfl,
-      type = "t",
-      return_data = TRUE
-    ),
-    "tbl"
-  )
-
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() table component_label",
-    ggcoef_multicomponents(
-      mod,
-      tidy_fun = broom.helpers::tidy_zeroinfl,
-      type = "t",
-      component_label = c(conditional = "Count", zero_inflated = "Zero-inflated") # nolint
-    )
-  )
-
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() faceted component_label",
-    ggcoef_multicomponents(
-      mod,
-      tidy_fun = broom.helpers::tidy_zeroinfl,
-      type = "f",
-      component_label = c(conditional = "Count", zero_inflated = "Zero-inflated")  # nolint
-    )
-  )
-
-  # message if unfound values for component_label
-  expect_message(
-    ggcoef_multicomponents(
-      mod,
-      tidy_fun = broom.helpers::tidy_zeroinfl,
-      type = "t",
-      component_label = c(c = "Count", zi = "Zero-inflated")
-    )
-  )
-
-  # error if unnamed values for component_label
-  expect_error(
-    ggcoef_multicomponents(
-      mod,
-      tidy_fun = broom.helpers::tidy_zeroinfl,
-      type = "t",
-      component_label = c("Count", zi = "Zero-inflated")
-    )
-  )
-
-  mod2 <- zeroinfl(art ~ fem + mar | 1, data = bioChemists)
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() mod2 table",
-    ggcoef_multicomponents(
-      mod2,
-      tidy_fun = broom.helpers::tidy_zeroinfl,
-      type = "t"
-    )
-  )
-
-  skip_if_not_installed("betareg")
-  skip_if_not_installed("parameters")
-
-  library(betareg)
-  data("GasolineYield", package = "betareg")
-  m1 <- betareg(yield ~ batch + temp, data = GasolineYield)
-  m2 <- betareg(yield ~ batch + temp | temp + pressure, data = GasolineYield)
-
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() betareg m1 table",
-    ggcoef_multicomponents(
-      m1,
-      type = "t",
-      tidy_fun = broom.helpers::tidy_parameters,
-      tidy_args = list(component = "all")
-    )
-  )
-
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() betareg m2 table",
-    ggcoef_multicomponents(
-      m2,
-      type = "t",
-      tidy_fun = broom.helpers::tidy_parameters,
-      tidy_args = list(component = "all")
-    )
-  )
-
-  modlm <- lm(Sepal.Length ~ Sepal.Width + Species, data = iris)
-
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() linear model table",
-    ggcoef_multicomponents(modlm, type = "t")
-  )
-
-  vdiffr::expect_doppelganger(
-    "ggcoef_multicomponents() linear model faceted",
-    ggcoef_multicomponents(modlm, type = "f")
-  )
 })
